@@ -1,5 +1,11 @@
 library(Zelig)
+
 data(turnout)
+
 z <- zelig(vote ~ race + educate + age, model = "logit", data = turnout)
-x <- setx(z, educate = 4:5, age=15:17)
-s <- sim(z, x, num=100)
+x <- setx(z, educate = 6:7, age = 17)
+s <- sim(z, x, num = 200)
+
+summary(s)
+
+plot(s)
